#[repr(u8)]pub enum AdjustmentCause {
Localoptimization = 0,
Gridoptimization = 1,
}Variants
Localoptimization = 0
The adjustment is to optimize the local energy usage
Gridoptimization = 1
The adjustment is to optimize the grid energy usage
Implementations