#[repr(u8)]pub enum OptOutState {
Nooptout = 0,
Localoptout = 1,
Gridoptout = 2,
Optout = 3,
}Variants
Nooptout = 0
The user has not opted out of either local or grid optimizations
Localoptout = 1
The user has opted out of local EMS optimizations only
Gridoptout = 2
The user has opted out of grid EMS optimizations only
Optout = 3
The user has opted out of all external optimizations
Implementations