#[repr(u8)]pub enum ESAState {
Offline = 0,
Online = 1,
Fault = 2,
Poweradjustactive = 3,
Paused = 4,
}Variants
Offline = 0
The ESA is not available to the EMS (e.g. start-up, maintenance mode)
Online = 1
The ESA is working normally and can be controlled by the EMS
Fault = 2
The ESA has developed a fault and cannot provide service
Poweradjustactive = 3
The ESA is in the middle of a power adjustment event
Paused = 4
The ESA is currently paused by a client using the PauseRequest command
Implementations